@@ -1,6 +1,7 @@
-#' The `tna` package.
+#' The `tna` Package.
 #'
 #' @name tna-package
+#' @family basic
 #' @description Provides tools for performing transition network analysis (TNA),
 #' including functions for building TNA models, plotting transition networks,
 #' and calculating centrality measures. The package relies on the `qgraph`
@@ -31,34 +32,56 @@
 #'
 "_PACKAGE"
 
-#' Example data on student engagement
+#' Example Data on Student Engagement
 #'
 #' Students' engagement states (Active / Average / Disengaged)
 #' throughout a whole study program. The data was generated synthetically
 #' based on the article "The longitudinal association between engagement and
-#' achievement varies by time, students’ profiles, and achievement state:
+#' achievement varies by time, students' profiles, and achievement state:
 #' A full program study"
 #'
-#' @family examples
+#' @family datasets
 #' @source \doi{10.1016/j.compedu.2023.104787}
 #' @format A `stslist` object (sequence data).
 "engagement"
 
-#' Example mixed Markov model fitted to the `engagement` data
+#' Example Mixed Markov Model Fitted to the `engagement` Data
 #'
-#' @family examples
+#' @family datasets
 #' @source The data was generated via `mixed_markov_model.R` in
 #' <https://github.com/sonsoleslp/tna/tree/main/data-raw/>
 #' @format A `mhmm` object.
 "engagement_mmm"
 
-#' Example data on group regulation
+# #' Example Mixed Markov Model Fitted to the `engagement` Data via TNA
+# #'
+# #' @family datasets
+# #' @source The data was generated via `mixed_markov_model.R` in
+# #' <https://github.com/sonsoleslp/tna/tree/main/data-raw/>
+# #' @format A `tna_mmm` object.
+# "engagement_tna_mmm"
+
+#' Example Wide Data on Group Regulation
 #'
 #' Students' regulation during collaborative learning. Students' interactions
 #' were coded as:  "adapt", "cohesion", "consensus", "coregulate", "discuss",
 #' "emotion", "monitor", "plan", "synthesis"
 #'
-#' @family examples
+#' @family datasets
 #' @source The data was generated synthetically.
 #' @format A `data.frame` object.
 "group_regulation"
+
+#' Example Long Data on Group Regulation
+#'
+#' Students' regulation during collaborative learning. This is the same dataset
+#' as `group_regulation` but in long format. In addition to students'
+#' actions (`Action`), it contains the student identifier (`Actor`),
+#' timestamp (`Time`), `Course` name, and collaboration `Group`. It
+#' also includes a column (`Achiever`) indicating whether the student
+#' is a high or low achiever.
+#'
+#' @family datasets
+#' @source The data was generated synthetically from `group_regulation`
+#' @format A `data.frame` object.
+"group_regulation_long"
